A Polkadot performance tests utilities.
Enums
Constants
- ERASURE_
CODING_ N_ VALIDATORS - Value used for reference benchmark of erasure-coding.
- ERASURE_
CODING_ TIME_ LIMIT - PVF_
PREPARE_ TIME_ LIMIT - VALIDATION_
CODE_ BOMB_ LIMIT - The bomb limit for decompressing code blobs.
- WASM_
BINARY
Functions
- measure_
erasure_ coding - Measure the time it takes to break arbitrary data into chunks and reconstruct it back.
- measure_
pvf_ prepare - Measures the time it takes to compile arbitrary wasm code.